pub struct Segment {
pub start_nm: f64,
pub start: Position,
pub band: Polygon<f64>,
}Expand description
A short piece of a leg, with the band around that piece.
Fields
start_nm: f64Distance from the start of the leg to where this piece begins.
start: PositionWhere this piece begins, on the leg itself.
band: Polygon<f64>The band of water around this piece.